-module(element_reset).
%%-author('Vladimir Galunshchikov').

-include_lib("nitro/include/nitro.hrl").
-include_lib("nitro/include/event.hrl").

-export([
  render_element/1
]).


render_element(Record) when Record#reset.show_if == false -> [<<>>];

render_element(Record) ->
  Id = case Record#reset.postback of
    [] -> Record#reset.id;
    Postback ->
      ID0 = case Record#reset.id of
        [] -> nitro:temp_id();
        I -> I
      end,
      nitro:wire( #event{type = click, postback = Postback, target = ID0,
                         source = Record#reset.source,
                         delegate = Record#reset.delegate} ),
      ID0
  end,
  List = [
    %% global
    {<<"accesskey">>, Record#reset.accesskey},
    {<<"class">>, Record#reset.class},
    {<<"contenteditable">>,
       case Record#reset.contenteditable of
         true -> "true";
         false -> "false";
         _ -> []
       end},
    
    {<<"contextmenu">>, Record#reset.contextmenu},
    {<<"dir">>,
       case Record#reset.dir of
         ltr -> "ltr";
         rtl -> "rtl";
         auto -> "auto";
         _ -> []
       end},
    
    {<<"draggable">>,
       case Record#reset.draggable of
         true -> "true";
         false -> "false";
         _ -> []
       end},
    
    {<<"dropzone">>, Record#reset.dropzone},
    {<<"hidden">>,
       case Record#reset.hidden of
         true -> "hidden";
         _ -> []
       end},
    
    {<<"id">>, Id},
    {<<"lang">>, Record#reset.lang},
    {<<"spellcheck">>,
       case Record#reset.spellcheck of
         true -> "true";
         false -> "false";
         _ -> []
       end},
    
    {<<"style">>, Record#reset.style},
    {<<"tabindex">>, Record#reset.tabindex},
    {<<"title">>, Record#reset.title},
    {<<"translate">>,
       case Record#reset.contenteditable of
         true -> "yes";
         false -> "no";
         _ -> []
       end},
    
    %% spec
    {<<"autofocus">>,
       case Record#reset.autofocus of
         true -> "autofocus";
         _ -> []
       end},
    
    {<<"disabled">>,
       case Record#reset.disabled of
         true -> "disabled";
         _ -> []
       end},
    
    {<<"form">>, Record#reset.form},
    {<<"name">>, Record#reset.name},
    {<<"type">>, <<"reset">>},
    {<<"value">>, Record#reset.value} | Record#reset.data_fields
  ],
  
  wf_tags:emit_tag(<<"input">>, nitro:render(Record#reset.body), List).

