-module(element_url).
%%-author('Vladimir Galunshchikov').

-include_lib("nitro/include/nitro.hrl").
-include_lib("nitro/include/event.hrl").

-export([
  render_element/1
]).


render_element(Record) when Record#url.show_if == false -> [<<>>];

render_element(Record) ->
  Id = case Record#url.postback of
    [] -> Record#url.id;
    Postback ->
      ID0 = case Record#url.id of
        [] -> nitro:temp_id();
        I -> I
      end,
      nitro:wire( #event{type = click, postback = Postback, target = ID0,
                         source = Record#url.source,
                         delegate = Record#url.delegate} ),
      ID0
  end,
  List = [
    %% global
    {<<"accesskey">>, Record#url.accesskey},
    {<<"class">>, Record#url.class},
    {<<"contenteditable">>,
       case Record#url.contenteditable of
         true -> "true";
         false -> "false";
         _ -> []
       end},
    
    {<<"contextmenu">>, Record#url.contextmenu},
    {<<"dir">>,
       case Record#url.dir of
         ltr -> "ltr";
         rtl -> "rtl";
         auto -> "auto";
         _ -> []
       end},
    
    {<<"draggable">>,
       case Record#url.draggable of
         true -> "true";
         false -> "false";
         _ -> []
       end},
    
    {<<"dropzone">>, Record#url.dropzone},
    {<<"hidden">>,
       case Record#url.hidden of
         true -> "hidden";
         _ -> []
       end},
    
    {<<"id">>, Id},
    {<<"lang">>, Record#url.lang},
    {<<"spellcheck">>,
       case Record#url.spellcheck of
         true -> "true";
         false -> "false";
         _ -> []
       end},
    
    {<<"style">>, Record#url.style},
    {<<"tabindex">>, Record#url.tabindex},
    {<<"title">>, Record#url.title},
    {<<"translate">>,
       case Record#url.contenteditable of
         true -> "yes";
         false -> "no";
         _ -> []
       end},
    
    %% spec
    {<<"autocomplete">>,
       case Record#url.autocomplete of
         true -> "on";
         false -> "off";
         _ -> []
       end},
    
    {<<"autofocus">>,
       case Record#url.autofocus of
         true -> "autofocus";
         _ -> []
       end},
    
    {<<"disabled">>,
       case Record#url.disabled of
         true -> "disabled";
         _ -> []
       end},
    
    {<<"form">>, Record#url.form},
    {<<"list">>, Record#url.list},
    {<<"maxlength">>, Record#url.maxlength},
    {<<"name">>, Record#url.name},
    {<<"pattern">>, Record#url.pattern},
    {<<"placeholder">>, Record#url.placeholder},
    {<<"readonly">>,
       case Record#url.readonly of
         true -> "readonly";
         _ -> []
       end},
    
    {<<"required">>,
       case Record#url.required of
         true -> "required";
         _ -> []
       end},
    
    {<<"size">>,Record#url.size},
    {<<"type">>, <<"url">>},
    {<<"value">>, Record#url.value} | Record#url.data_fields
  ],
  
  wf_tags:emit_tag(<<"input">>, nitro:render(Record#url.body), List).

